## Mongo Analyser

[![Tests](https://img.shields.io/github/actions/workflow/status/habedi/mongo-analyser/tests.yml?label=tests)](https://github.com/habedi/mongo-analyser/actions/workflows/tests.yml)
[![Lint](https://img.shields.io/github/actions/workflow/status/habedi/mongo-analyser/lints.yml?label=lints)](https://github.com/habedi/mongo-analyser/actions/workflows/lints.yml)
[![codecov](https://codecov.io/gh/habedi/mongo-analyser/graph/badge.svg?token=HOTAZKP3V7)](https://codecov.io/gh/habedi/mongo-analyser)
[![CodeFactor](https://www.codefactor.io/repository/github/habedi/mongo-analyser/badge)](https://www.codefactor.io/repository/github/habedi/mongo-analyser)
[![PyPI version](https://badge.fury.io/py/mongo-analyser.svg)](https://badge.fury.io/py/mongo-analyser)
[![Pip downloads](https://img.shields.io/pypi/dm/mongo-analyser.svg)](https://pypi.org/project/mongo-analyser)
<br>
[![Python version](https://img.shields.io/badge/Python-%3E=3.9-blue?)](https://github.com/habedi/mongo-analyser)
[![Documentation](https://img.shields.io/badge/docs-latest-blue)](https://github.com/habedi/mongo-analyser/blob/main/docs/README.md)
[![License](https://img.shields.io/badge/license-MIT-blue)](https://github.com/habedi/mongo-analyser/blob/main/LICENSE)

Mongo Analyser is a Python library and command-line tool that can help people analyze and infer the schemas
of MongoDB collections.
It can also be used to extract data from MongoDB collections and store it in a compressed JSON file.

### Installation

Mongo Analyser can be installed using pip as a Python library:

```bash
pip install mongo-analyser
```

It can also be installed using pipx or uv as a standalone command-line tool:

```bash
pipx install mongo-analyser
```

```bash
uv tool install mongo-analyser
```

### Documentation

See the [docs](docs) directory for more information on how to use Mongo Analyser.

#### Command-line Usage Demo

[![asciicast](https://asciinema.org/a/682346.svg)](https://asciinema.org/a/682346)

### License

Mongo Analyser is licensed under the [MIT License](LICENSE).
